@@ -19,6 +19,9 @@
  */
 class Moony_Request
 {
+    /** @var object Moony_Sessionのインスタンス */
+    var $session;
+
     /** @var array 実際のパラメータを格納する配列 */
     var $params;
 
@@ -32,9 +35,12 @@ class Moony_Request
      * コンストラクタです。
      * 
      * @access public
+     * @param object $session Moony_Sessionのインスタンス
      */
-    function Moony_Request()
+    function Moony_Request(&$session)
     {
+        $this->session = &$session;
+
         // リクエストパラメータ
         $this->params = (strtolower($_SERVER['REQUEST_METHOD']) == 'post') ? $_POST : $_GET;
         $this->files = $_FILES;
@@ -54,7 +60,7 @@ class Moony_Request
         }
 
         // PATH_INFO取得、拡張子除去
-        $path_info = Moony_Utils::getPathInfo();
+        $path_info = Moony_Utils::getEnvVar('PATH_INFO', '');
         $path_info = Moony_Utils::removeFileExtension($path_info);
 
         // スラッシュ区切りで分割、不要部分除去
@@ -158,18 +164,17 @@ class Moony_Request
      * 比較後、セッション内のトークン値は直ちに削除されます。
      *
      * @access public
-     * @param object $session Moony_Sessionのインスタンス
      * @return boolean トークンがセッションに格納された値と一致する場合true
      */
-    function checkToken(&$session)
+    function checkToken()
     {
-        if (!$session->hasStarted() || !$this->exists(MOONY_TRANSACTION_TOKEN_NAME)) {
+        if (!$this->session->hasStarted() || !$this->exists(MOONY_TRANSACTION_TOKEN_NAME)) {
             return false;
         }
 
         // セッションから保存しておいたトークン値取得、直ちにセッションから削除
-        $saved = $session->get(MOONY_TRANSACTION_TOKEN_NAME);
-        $session->remove(MOONY_TRANSACTION_TOKEN_NAME);
+        $saved = $this->session->get(MOONY_TRANSACTION_TOKEN_NAME);
+        $this->session->remove(MOONY_TRANSACTION_TOKEN_NAME);
 
         // リクエストパラメータと比較
         if ($this->get(MOONY_TRANSACTION_TOKEN_NAME) === $saved) {
