@@ -80,11 +80,12 @@ class Moony_Uploader
      *
      * @access public
      * @param string $save_dir 保存先のディレクトリ名
+     * @param string|array $save_name 保存先のファイル名（配列を処理する場合、配列で指定）
      * @param integer $file_mode 保存したファイルのパーミッション（8進数で指定）
      * @param boolean $on_error_remove 処理途中でエラーが発生した場合、アップロード済みのファイルを削除するかどうか
      * @return boolean 全てのアップロードが成功した場合true、そうでない場合false
      */
-    function upload($save_dir, $file_mode = 0644, $on_error_remove = false)
+    function upload($save_dir, $save_name, $file_mode = 0644, $on_error_remove = false)
     {
         // 対象が確定されているか
         if (is_null($this->file)) {
@@ -104,6 +105,15 @@ class Moony_Uploader
                 return false;
             }
         }
+        // ファイル名の指定が正しいかどうか
+        if (is_array($this->file['name'])) {
+            if (!is_array($save_name) && count($save_name) < count($this->file['name'])) {
+                Moony_Logger::warn('File name not set: ' . $save_name,  __FILE__, __LINE__);
+                return false;
+            }
+        } else {
+            $save_name = is_array($save_name) ? $save_name[0] : $save_name;
+        }
         // ファイル名エンコーディングの変換
         if ($this->encoding != MOONY_INTERNAL_ENCODING) {
             if (is_array($this->file['name'])) { 
@@ -115,9 +125,10 @@ class Moony_Uploader
         // アップロード処理
         if (is_array($this->file['name'])) {
             $paths = array();
+            $i = 0;
             foreach ($this->file['name'] as $key => $name) {
                 if ($this->file['error'][$key] == UPLOAD_ERR_OK) {
-                    $save_path = Moony_Utils::buildPath($save_dir, $name);
+                    $save_path = Moony_Utils::buildPath($save_dir, $save_name[$i]);
                     if (move_uploaded_file($this->file['tmp_name'][$key], $save_path)) {
                         chmod($save_path, $file_mode);
                         $paths[] = $save_path;
@@ -131,10 +142,11 @@ class Moony_Uploader
                         return false;
                     }
                 }
+                $i++;
             }
         } else {
             if ($this->file['error'] == UPLOAD_ERR_OK) {
-                $save_path = Moony_Utils::buildPath($save_dir, $this->file['name']);
+                $save_path = Moony_Utils::buildPath($save_dir, $save_name);
                 if (move_uploaded_file($this->file['tmp_name'], $save_path)) {
                     chmod($save_path, $file_mode);
                 } else {
@@ -169,5 +181,16 @@ class Moony_Uploader
         }
         return false;
     }
+
+    /**
+     * アップロードファイルの元の名称を取得します。
+     *
+     * @access public
+     * @return string|array アップロードファイルの元の名称
+     */
+    function getOriginalName()
+    {
+        return $this->file['name'];
+    }
 }
 ?>
