@@ -136,17 +136,18 @@ class Moony_Utils
     }
 
     /**
-     * PATH_INOを取得します。
-     * 取得できない場合、無条件に長さ0の文字列を返します。
+     * Nul文字を取り除いた環境変数（$_SERVER）の値を取得します。
      *
      * @access public
      * @static
-     * @return string PATH_INFO
+     * @param string $name 取得したい環境変数のキー/名称
+     * @param mixed $alt 該当の環境変数が存在しない場合の代替値
+     * @return mixed 該当する環境変数の値
      */
-    function getPathInfo()
+    function getEnvVar($name, $alt)
     {
-        $path_info = Moony_Utils::getArrayValue('PATH_INFO', $_SERVER, '');
-        return Moony_Utils::removeNulString($path_info);
+        $value = Moony_Utils::getArrayValue($name, $_SERVER, $alt);
+        return Moony_Utils::removeNulString($value);
     }
 
     /**
